simple_jwt_manager library

Classes

ErrorReporter
(en) A general purpose error reporting class.
ErrorReporterForNative
(en) An error reporting class for native devices. This supports the use of self-signed certificates.
ErrorReportObj
(en) This is an object for storing basic error content used by ErrorReporter and ErrorReporterForNative.
ROPCAuthStream
(en) A stream for managing the sign-in and sign-out states.
ROPCClient
(en) This class manages JWT tokens and controls login, as defined in the Resource Owner Password Credentials Grant defined in RFC 6749.
ROPCClientForNative
(en) This class manages JWT tokens and controls login, as defined in the Resource Owner Password Credentials Grant defined in RFC 6749. This class is not available in Flutter web.
ServerResponse
(en) This class is used to store return values from the server. It stores statuses categorized in an easy to use way.
TimingManager
(en) A manager that allows you to adjust timing when POSTing via https, etc. This can be useful, for example, when there is a write limit (x items/second) on the backend. This works with singletons.
UtilCheckURL
(en) A utility for checking communication security.
UtilHttps
UtilHttpsForNative
UtilServerResponse
(en) A utility for formatting server responses.

Enums

EnumAuthStatus
EnumPostEncodeType
(en) Specifies the encode type for simple POST.
EnumServerResponseStatus
(en) To simplify responses from the server, This is an enum that classifies the response content into five types: successful processing, timeout(connection or response), server error, other error, SignIn required.
EnumServerResponseType